<?php

if (!defined('ABSPATH')) {
    exit;
}

final class Kirimemail_Woocommerce
{
    const KIRIMWOO_PLUGIN_VERSION = '1.2.9';
    private static $_instance = null;

    /**
     * @var Kemail_Wc_Api
     */
    public $KIRIMWOO_API = null;

    /**
     * Main Kirimemail Instance.
     *
     * Ensures only one instance of Kirimemail is loaded or can be loaded.
     *
     * @return Kirimemail_Woocommerce - Main instance.
     * @see WC()
     * @since 2.1
     * @static
     */
    public static function instance()
    {
        if (is_null(self::$_instance)) {
            self::$_instance = new self();
        }

        return self::$_instance;
    }

    public function __construct()
    {
        $this->define_constant();
        $this->_include();
        $this->KIRIMWOO_API = new Kemail_Wc_Api();
        $this->add_menu();
        $this->init_hooks();
    }

    public function __clone()
    {
        kewc_doing_it_wrong(__FUNCTION__, __('Cheatin&#8217; huh?', 'kirimemail_woocommerce'), '1.1.0');
    }

    public function __wakeup()
    {
        kewc_doing_it_wrong(__FUNCTION__, __('Cheatin&#8217; huh?', 'kirimemail_woocommerce'), '1.1.0');
    }

    protected function define_constant()
    {
        $this->define('KIRIMWOO_ABSPATH', dirname(KIRIMWOO_PLUGIN_FILE) . '/');
    }

    protected function _include()
    {
        include_once(KIRIMWOO_ABSPATH . 'includes/class-kemail-autoloader.php');
        include_once(KIRIMWOO_ABSPATH . 'includes/kemail-core-function.php');
        include_once(KIRIMWOO_ABSPATH . 'includes/lib/class-kemail-wc-api.php');
    }

    protected function init_hooks()
    {
        if (get_option('ke_order_pending_list') != 0) {
            add_action('woocommerce_order_status_pending', array($this, 'on_order_pending'));
        }
        if (get_option('ke_order_created_list') != 0) {
            add_action('woocommerce_thankyou', array($this, 'on_order_created'));
        }
        if (get_option('ke_order_processed_list') != 0) {
            add_action('woocommerce_order_status_processing', array($this, 'on_order_processed'));
        }
        if (get_option('ke_order_completed_list') != 0) {
            add_action('woocommerce_order_status_completed', array($this, 'on_order_completed'));
        }
    }

    public function add_menu()
    {
        if (is_admin()) {
            add_action('admin_menu', array($this, 'admin_menu'));
            add_action('admin_notices', array($this, 'display_notice'));
            if (isset($_GET['page']) && $_GET['page'] == 'kirimemail-woocommerce') {
                add_action('admin_enqueue_scripts', array(&$this, 'enqueue_scripts'));
            }

            if (!empty($_SERVER['HTTP_X_REQUESTED_WITH'])) {
                if (isset($_GET['get_list'])) {
                    $this->KIRIMWOO_API->get_list();
                }
            }
        }
    }

    public function display_notice()
    {
        global $hook_suffix;
        if ($hook_suffix == 'plugins.php' && !get_option('ke_wc_api_username')) {
            kewc_load_view('notice', ['type' => 'plugins']);
        }
        if ($hook_suffix == 'plugins.php' && !is_plugin_active('woocommerce/woocommerce.php')) {
            kewc_load_view('notice', ['type' => 'plugins-woocommerce']);
        }
    }

    public function page()
    {
        if (!empty($_POST)) {
            self::save();
        }
        $type = 'normal';
        if (!is_plugin_active('woocommerce/woocommerce.php')) {
            $type = 'no-woocommerce';
        } elseif (!get_option('ke_wc_api_username')) {
            $type = 'no-account';
        } else {
            $type = 'normal';
        }

        $data = array(
            'logo' => kewc_get_asset('images/ke-logo.svg'),
            'alert' => kewc_get_asset('images/icon-alert.svg'),
            'blank' => kewc_get_asset('images/icon-blank.svg'),
            'type' => $type,
        );

        kewc_load_view('index', $data);
    }

    public static function save()
    {
        if (isset($_POST['api_username'])) {
            update_option('ke_wc_api_username', sanitize_user($_POST['api_username']));
        }

        if (isset($_POST['api_token'])) {
            update_option('ke_wc_api_token', sanitize_text_field($_POST['api_token']));
        }

        if (isset($_POST['on_pending'])) {
            update_option('ke_order_pending_list', sanitize_text_field($_POST['on_pending']));
        }

        if (isset($_POST['on_created'])) {
            update_option('ke_order_created_list', sanitize_text_field($_POST['on_created']));
        }

        if (isset($_POST['on_processed'])) {
            update_option('ke_order_processed_list', sanitize_text_field($_POST['on_processed']));
        }

        if (isset($_POST['on_completed'])) {
            update_option('ke_order_completed_list', sanitize_text_field($_POST['on_completed']));
        }
    }

    public function on_order_pending($order_id = 0)
    {
        $this->KIRIMWOO_API->subscribe($order_id, 'ke_order_pending_list');
    }

    public function on_order_created($order_id = 0)
    {
        $this->KIRIMWOO_API->subscribe($order_id, 'ke_order_created_list');
    }

    public function on_order_processed($order_id = 0)
    {
        $this->KIRIMWOO_API->subscribe($order_id, 'ke_order_processed_list');
    }

    public function on_order_completed($order_id = 0)
    {
        $this->KIRIMWOO_API->subscribe($order_id, 'ke_order_completed_list');
    }

    public function admin_menu()
    {
        add_menu_page(__('Kirim.Email WooCommerce Integration', 'kirimemail_woocommerce'),
            __('Kirim.Email WooCommerce Integration', 'kirimemail_woocommerce'),
            'manage_woocommerce',
            'kirimemail-woocommerce',
            array($this, 'page'),
            kewc_get_asset('images/icon.png'));
    }

    public function enqueue_scripts()
    {
        wp_enqueue_style('kirimemail-style', kewc_get_asset('css/style.css'), false, self::KIRIMWOO_PLUGIN_VERSION, 'all');
        wp_enqueue_script('jQuery');
        wp_register_script('kirimemail-script', kewc_get_asset('js/kirimemail-woocommerce.js'), 'jQuery', self::KIRIMWOO_PLUGIN_VERSION, true);
        wp_localize_script('kirimemail-script', 'kirimemail', array(
            'admin_url' => admin_url(),
            'order_pending_list' => isset($_POST['on_pending']) ? sanitize_text_field($_POST['on_pending']) : get_option('ke_order_pending_list'),
            'order_created_list' => isset($_POST['on_created']) ? sanitize_text_field($_POST['on_created']) : get_option('ke_order_created_list'),
            'order_processed_list' => isset($_POST['on_processed']) ? sanitize_text_field($_POST['on_processed']) : get_option('ke_order_processed_list'),
            'order_completed_list' => isset($_POST['on_completed']) ? sanitize_text_field($_POST['on_completed']) : get_option('ke_order_completed_list'),
        ));
        wp_enqueue_script('kirimemail-script');
    }

    /**
     * Define constant if not already set.
     *
     * @param string $name Constant name.
     * @param string|bool $value Constant value.
     */
    private function define($name, $value)
    {
        if (!defined($name)) {
            define($name, $value);
        }
    }
}
