<?php if (!defined('ABSPATH')) {
    exit;
}

class Kemail_Wc_Api
{
    public function api_request($url, $method, $args = [])
    {
        $url = KIRIMWOO_API_URL . $url;

        $timestamp = time();
        $api_username = isset($args['api_username']) ? $args['api_username'] : get_option('ke_wc_api_username');
        $api_token = isset($args['api_token']) ? $args['api_token'] : get_option('ke_wc_api_token');

        $auth_str = rtrim(ltrim($api_username)) . "::" . rtrim(ltrim($api_token)) . "::" . $timestamp;
        $token = hash_hmac("sha256", $auth_str, rtrim(ltrim($api_token)));

        $request_args = array(
            'method' => $method,
            'sslverify' => false,
            'timeout' => 60,
            'redirection' => 5,
            'httpversion' => '1.1',
            'headers' => array(
                'Auth-Id' => $api_username,
                'Auth-Token' => $token,
                'Timestamp' => $timestamp,
                'User-Agent' => 'KirimEmail/WooCommerce'
            ),
        );

        // attach arguments (in body or URL)
        if ($method === 'POST') {
            $request_args['body'] = http_build_query($args);
        }

        $raw_response = wp_remote_request($url, $request_args);

        if (is_wp_error($raw_response)) {
            return false;
        } else {
            $json = wp_remote_retrieve_body($raw_response);
            $result = json_decode($json, true);

            return $result;
        }
    }

    public function get_list($args = array())
    {
        $list_data = $this->api_request('list?nolimit=true', 'GET', $args);

        if ($list_data && $list_data['code'] == 200) {
            echo '<option value="0">-- Dont Save --</option>';

            foreach ($list_data['data'] as $list) {
                echo '<option value="' . esc_attr($list['id']) . '">' . esc_html($list['name']) . '</option>';
            }
        }
        die();
    }

    public function check_list($args = array())
    {
        $list_data = $this->api_request('list?nolimit=true', 'GET', $args);

        if ($list_data && $list_data['code'] == 200) {
            return count($list_data['data']);
        } else {
            return - 1;
        }
    }

    public function subscribe($order_id, $type)
    {
        $full_name = get_post_meta($order_id, '_billing_first_name', true) . ' ' . get_post_meta($order_id, '_billing_last_name', true);
        $email = get_post_meta($order_id, '_billing_email', true);
        $phone = get_post_meta($order_id, '_billing_phone', true);

        $args = array(
            'full_name' => $full_name,
            'email' => $email,
            'fields' => ['woocommerce-order-phone' => $phone],
            'lists' => [get_option($type)]
        );

        $this->api_request('subscriber', 'POST', $args);
    }
}
